@@ -36,7 +36,7 @@
 #include <KCalCore/ICalFormat>
 
 #include <QJsonDocument>
-
+#include <QUrlQuery>
 #include <QTimeZone>
 #include <QVariant>
 
@@ -93,7 +93,7 @@ QUrl fetchCalendarUrl(const QString& calendarID)
 QUrl updateCalendarUrl(const QString &calendarID)
 {
     QUrl url(Private::GoogleApisUrl);
-    url.setPath(Private::CalendarListBasePath % QLatin1Char('/') % calendarID);
+    url.setPath(Private::CalendarBasePath % QLatin1Char('/') % calendarID);
     return url;
 }
 
@@ -115,7 +115,9 @@ QUrl fetchEventsUrl(const QString& calendarID)
 {
     QUrl url(Private::GoogleApisUrl);
     url.setPath(Private::CalendarBasePath % QLatin1Char('/') % calendarID % QLatin1String("/events"));
-    url.addQueryItem(QStringLiteral("maxResults"), QStringLiteral("20"));
+    QUrlQuery query(url);
+    query.addQueryItem(QStringLiteral("maxResults"), QStringLiteral("20"));
+    url.setQuery(query);
     return url;
 }
 
@@ -151,7 +153,9 @@ QUrl moveEventUrl(const QString& sourceCalendar, const QString& destCalendar, co
 {
     QUrl url(Private::GoogleApisUrl);
     url.setPath(Private::CalendarBasePath % QLatin1Char('/') % sourceCalendar % QLatin1String("/events/") % eventID);
-    url.addQueryItem(QStringLiteral("destination"), destCalendar);
+    QUrlQuery query(url);
+    query.addQueryItem(QStringLiteral("destination"), destCalendar);
+    url.setQuery(query);
     return url;
 }
 
@@ -251,10 +255,12 @@ ObjectsList parseCalendarJSONFeed(const QByteArray& jsonFeed, FeedData& feedData
     if (data.value(QStringLiteral("kind")) == QLatin1String("calendar#calendarList")) {
         if (data.contains(QStringLiteral("nextPageToken"))) {
             feedData.nextPageUrl = fetchCalendarsUrl();
-            feedData.nextPageUrl.addQueryItem(QStringLiteral("pageToken"), data.value(QStringLiteral("nextPageToken")).toString());
-            if (feedData.nextPageUrl.queryItemValue(QStringLiteral("maxResults")).isEmpty()) {
-                feedData.nextPageUrl.addQueryItem(QStringLiteral("maxResults"),QStringLiteral("20"));
+            QUrlQuery query(feedData.nextPageUrl);
+            query.addQueryItem(QStringLiteral("pageToken"), data.value(QStringLiteral("nextPageToken")).toString());
+            if (query.queryItemValue(QStringLiteral("maxResults")).isEmpty()) {
+                query.addQueryItem(QStringLiteral("maxResults"),QStringLiteral("20"));
             }
+            feedData.nextPageUrl.setQuery(query);
         }
     } else {
         return ObjectsList();
@@ -271,9 +277,12 @@ ObjectsList parseCalendarJSONFeed(const QByteArray& jsonFeed, FeedData& feedData
 
 EventPtr JSONToEvent(const QByteArray& jsonData)
 {
-    QJsonDocument document = QJsonDocument::fromJson(jsonData);
+    QJsonParseError error;
+    QJsonDocument document = QJsonDocument::fromJson(jsonData, &error);
+    if (error.error != QJsonParseError::NoError) {
+        qCWarning(KGAPIDebug) << "Error parsing event JSON: " << error.errorString();
+    }
     QVariantMap data = document.toVariant().toMap();
-
     if (data.value(QStringLiteral("kind")) != QLatin1String("calendar#event")) {
         return EventPtr();
     }
@@ -410,7 +419,13 @@ ObjectPtr Private::JSONToEvent(const QVariantMap& data, const QString &timezone)
         if (att.value(QStringLiteral("optional")).toBool()) {
             attendee->setRole(KCalCore::Attendee::OptParticipant);
         }
-
+        const auto uid = att.value(QStringLiteral("id")).toString();
+        if (!uid.isEmpty()) {
+            attendee->setUid(uid);
+        } else {
+            // Set some UID, just so that the results are reproducible
+            attendee->setUid(QString::number(qHash(attendee->email())));
+        }
         event->addAttendee(attendee, true);
     }
 
@@ -505,7 +520,7 @@ QByteArray eventToJSON(const EventPtr& event)
     QVariantMap data;
 
     /* Type */
-    data.insert(QStringLiteral("type"), QStringLiteral("calendar#event"));
+    data.insert(QStringLiteral("kind"), QStringLiteral("calendar#event"));
 
     /* ID */
     if (!event->uid().isEmpty()) {
@@ -573,16 +588,16 @@ QByteArray eventToJSON(const EventPtr& event)
     /* Start */
     QVariantMap start;
     if (event->allDay()) {
-        start.insert(QStringLiteral("date"), event->dtStart().toString(QStringLiteral("%Y-%m-%d")));
+        start.insert(QStringLiteral("date"), event->dtStart().toString(QStringLiteral("yyyy-MM-dd")));
     } else {
         start.insert(QStringLiteral("dateTime"), Utils::rfc3339DateToString(event->dtStart()));
-    }
-    QString tzStart = QString::fromUtf8(event->dtStart().timeZone().id());
-    if (!recurrence.isEmpty() && tzStart.isEmpty()) {
-        tzStart = QString::fromUtf8(QTimeZone::utc().id());
-    }
-    if (!tzStart.isEmpty()) {
-        start.insert(QStringLiteral("timeZone"), Private::checkAndConverCDOTZID(tzStart, event));
+        QString tzStart = QString::fromUtf8(event->dtStart().timeZone().id());
+        if (!recurrence.isEmpty() && tzStart.isEmpty()) {
+            tzStart = QString::fromUtf8(QTimeZone::utc().id());
+        }
+        if (!tzStart.isEmpty()) {
+            start.insert(QStringLiteral("timeZone"), Private::checkAndConverCDOTZID(tzStart, event));
+        }
     }
     data.insert(QStringLiteral("start"), start);
 
@@ -592,16 +607,16 @@ QByteArray eventToJSON(const EventPtr& event)
         /* For Google, all-day events starts on Monday and ends on Tuesday,
          * while in KDE, it both starts and ends on Monday. */
         QDateTime dtEnd = event->dtEnd().addDays(1);
-        end.insert(QStringLiteral("date"), dtEnd.toString(QStringLiteral("%Y-%m-%d")));
+        end.insert(QStringLiteral("date"), dtEnd.toString(QStringLiteral("yyyy-MM-dd")));
     } else {
         end.insert(QStringLiteral("dateTime"), Utils::rfc3339DateToString(event->dtEnd()));
-    }
-    QString tzEnd = QString::fromUtf8(event->dtEnd().timeZone().id());
-    if (!recurrence.isEmpty() && tzEnd.isEmpty()) {
-        tzEnd = QString::fromUtf8(QTimeZone::utc().id());
-    }
-    if (!tzEnd.isEmpty()) {
-        end.insert(QStringLiteral("timeZone"), Private::checkAndConverCDOTZID(tzEnd, event));
+        QString tzEnd = QString::fromUtf8(event->dtEnd().timeZone().id());
+        if (!recurrence.isEmpty() && tzEnd.isEmpty()) {
+            tzEnd = QString::fromUtf8(QTimeZone::utc().id());
+        }
+        if (!tzEnd.isEmpty()) {
+            end.insert(QStringLiteral("timeZone"), Private::checkAndConverCDOTZID(tzEnd, event));
+        }
     }
     data.insert(QStringLiteral("end"), end);
 
@@ -633,7 +648,9 @@ QByteArray eventToJSON(const EventPtr& event)
         if (attee->role() == KCalCore::Attendee::OptParticipant) {
             att.insert(QStringLiteral("optional"), true);
         }
-
+        if (!attee->uid().isEmpty()) {
+            att.insert(QStringLiteral("id"), attee->uid());
+        }
         atts.append(att);
     }
 
@@ -703,11 +720,13 @@ ObjectsList parseEventJSONFeed(const QByteArray& jsonFeed, FeedData& feedData)
             calendarId = calendarId.left(calendarId.indexOf(QLatin1Char('/')));
             feedData.nextPageUrl = feedData.requestUrl;
             // replace the old pageToken with a new one
-            feedData.nextPageUrl.removeQueryItem(QStringLiteral("pageToken"));
-            feedData.nextPageUrl.addQueryItem(QStringLiteral("pageToken"), data.value(QStringLiteral("nextPageToken")).toString());
-            if (feedData.nextPageUrl.queryItemValue(QStringLiteral("maxResults")).isEmpty()) {
-                feedData.nextPageUrl.addQueryItem(QStringLiteral("maxResults"), QStringLiteral("20"));
+            QUrlQuery query(feedData.nextPageUrl);
+            query.removeQueryItem(QStringLiteral("pageToken"));
+            query.addQueryItem(QStringLiteral("pageToken"), data.value(QStringLiteral("nextPageToken")).toString());
+            if (query.queryItemValue(QStringLiteral("maxResults")).isEmpty()) {
+                query.addQueryItem(QStringLiteral("maxResults"), QStringLiteral("20"));
             }
+            feedData.nextPageUrl.setQuery(query);
         }
         if (data.contains(QStringLiteral("timeZone"))) {
             // This should always be in Olson format
